# mfNRcatpy

mfNRcatpy is a Python package for Gravitational-wave data analysis,
created and mantained by Sebastian Gomez Lopez.

This package contains several tolls that allow working with 
binary neutron star numerical relativity waveform catalogs 
and the matched filtering algorithm.
